Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(193)

Unified Diff: webkit/browser/fileapi/syncable/syncable_file_system_operation.h

Issue 21370003: Rename fileapi::LocalFileSystemOperation to FileSystemOperationImpl. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Rebase Created 7 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webkit/browser/fileapi/syncable/syncable_file_system_operation.h
diff --git a/webkit/browser/fileapi/syncable/syncable_file_system_operation.h b/webkit/browser/fileapi/syncable/syncable_file_system_operation.h
index e8e5c6536f354829eb39f0ab5a4ceead7e022bbb..a47d6e2cf847aa3cde39617df1fb59a5258c566e 100644
--- a/webkit/browser/fileapi/syncable/syncable_file_system_operation.h
+++ b/webkit/browser/fileapi/syncable/syncable_file_system_operation.h
@@ -12,7 +12,7 @@
#include "base/memory/scoped_ptr.h"
#include "base/memory/weak_ptr.h"
#include "base/threading/non_thread_safe.h"
-#include "webkit/browser/fileapi/local_file_system_operation.h"
+#include "webkit/browser/fileapi/file_system_operation_impl.h"
#include "webkit/browser/webkit_storage_browser_export.h"
namespace fileapi {
@@ -25,9 +25,9 @@ namespace sync_file_system {
class SyncableFileOperationRunner;
// A wrapper class of LocalFileSystemOperation for syncable file system.
class WEBKIT_STORAGE_BROWSER_EXPORT SyncableFileSystemOperation
- : public fileapi::LocalFileSystemOperation,
+ : public fileapi::FileSystemOperationImpl,
public base::SupportsWeakPtr<SyncableFileSystemOperation>,
public base::NonThreadSafe {
public:
@@ -76,7 +76,7 @@ class WEBKIT_STORAGE_BROWSER_EXPORT SyncableFileSystemOperation
const fileapi::FileSystemURL& path,
const SnapshotFileCallback& callback) OVERRIDE;
- // LocalFileSystemOperation overrides.
+ // FileSystemOperationImpl overrides.
virtual void CopyInForeignFile(const base::FilePath& src_local_disk_path,
const fileapi::FileSystemURL& dest_url,
const StatusCallback& callback) OVERRIDE;
@@ -94,7 +94,7 @@ class WEBKIT_STORAGE_BROWSER_EXPORT SyncableFileSystemOperation
const fileapi::FileSystemURL& url,
fileapi::FileSystemContext* file_system_context,
scoped_ptr<fileapi::FileSystemOperationContext> operation_context);
- fileapi::LocalFileSystemOperation* NewOperation();
+ fileapi::FileSystemOperationImpl* NewOperation();
void DidFinish(base::PlatformFileError status);
void DidWrite(const WriteCallback& callback,
@@ -107,7 +107,7 @@ class WEBKIT_STORAGE_BROWSER_EXPORT SyncableFileSystemOperation
const fileapi::FileSystemURL url_;
base::WeakPtr<SyncableFileOperationRunner> operation_runner_;
- scoped_ptr<fileapi::LocalFileSystemOperation> inflight_operation_;
+ scoped_ptr<fileapi::FileSystemOperationImpl> inflight_operation_;
std::vector<fileapi::FileSystemURL> target_paths_;
StatusCallback completion_callback_;
@@ -25,9 +25,9 @@ namespace sync_file_system {
class SyncableFileOperationRunner;
-// A wrapper class of LocalFileSystemOperation for syncable file system.
+// A wrapper class of FileSystemOperationImpl for syncable file system.
class WEBKIT_STORAGE_BROWSER_EXPORT SyncableFileSystemOperation

Powered by Google App Engine
This is Rietveld 408576698